==> yass-1.09.tar.gz: yass-1.09/prdyn.h <==
/*
 *  YASS 1.09
 *  Copyright (C) 2004,2005
 *  YASS Team
 *  Laurent Noe, Gregory Kucherov, Mikhail Roytberg, Christophe Valmir, Steven Corroy
 *  yass@loria.fr
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software contains code derived from the GNU libavl library.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef __PRDYN_H_
#define __PRDYN_H_
#include "tuple.h"
#include "global_var.h"

int initialise_alignment(int size,Feature_assemble *feature);


int left_alignment(char *data1, int pos1, int len1,
		   char *data2, int pos2, int len2,
		   double leavethreshold, int steps_to_leave,
		   /*out */ int *p_gain_score,
		   /*out */ int *p_last_pos1,
		   /*out */ int *p_last_pos2,
		   Feature_assemble *feature
		   );

int right_alignment(char *data1, int pos1, int len1,
		    char *data2, int pos2, int len2,
		    double leavethreshold, int steps_to_leave,
		    /*out */ int *p_gain_score,
		    /*out */ int *p_last_pos1,
		    /*out */ int *p_last_pos2,
		    Feature_assemble *feature
		    );

int left_alignment_SG(char *data1, int pos1, int len1,
		      char *data2, int pos2, int len2, int XDROP,
		      /*out */ int *p_gainscore,
		      /*out */ int *p_last_pos1,
		      /*out */ int *p_last_pos2,
		      Feature_assemble *feature
		      );

int right_alignment_SG(char *data1, int pos1, int len1,
		       char *data2, int pos2, int len2, int XDROP,
		       /*out */ int *p_gainscore,
		       /*out */ int *p_last_pos1,
		       /*out */ int *p_last_pos2,
		       Feature_assemble *feature
		       );

int left_alignment_SG_Lz(char *data1, int pos1, int len1,
			 char *data2, int pos2, int len2, int XDROP,
			 /*out */ int *p_gainscore,
			 /*out */ int *p_last_pos1,
			 /*out */ int *p_last_pos2,
			 Feature_assemble *feature
			 );

int right_alignment_SG_Lz(char *data1, int pos1, int len1,
			  char *data2, int pos2, int len2, int XDROP,
			  /*out */ int *p_gainscore,
			  /*out */ int *p_last_pos1,
			  /*out */ int *p_last_pos2,
			  Feature_assemble *feature
			  );

int left_alignment_SG_Border(char *data1, int pos1, int len1,
			     char *data2, int pos2, int len2, int XDROP,
			     /*out */ int *p_gainscore,
			     /*out */ int *p_last_pos1,
			     /*out */ int *p_last_pos2,
			     Feature_assemble *feature
			     );

int right_alignment_SG_Border(char *data1, int pos1, int len1,
			      char *data2, int pos2, int len2, int XDROP,
			      /*out */ int *p_gainscore,
			      /*out */ int *p_last_pos1,
			      /*out */ int *p_last_pos2,
			      Feature_assemble *feature
			      );


/*-----------------------------------------------------------------*/

/* alignment methods:
 *
 * WARNING : set in "data1" its reversed complementary "datarev" 
 * if needed.
 * coordonninate "pos1" must then be explicitely expressed  
 * (as  (datasize1 - k + 1) - pos1).
 */

int alignment(char *data1, int pos1, int len1,
	      char *data2, int pos2, int len2,
	      Feature_assemble *feature);

int alignment_SG(char *data1, int pos1, int len1,
		 char *data2, int pos2, int len2,
		 Feature_assemble *feature);

int alignment_SG_Strait(char *data1, int pos1,
			char *data2, int pos2, int len,
			Feature_assemble *feature);

int alignment_SG_DROP(char *data1, int pos1, int len1,
		      char *data2, int pos2, int len2, int XDROP,
		      Feature_assemble *feature);


int alignment_SG_DROP_opt(char *data1, int pos1, int len1,
			  char *data2, int pos2, int len2, int XDROP,
			  Feature_assemble *feature);

int alignment_SG_Lz(char *data1, int pos1, int len1,
		    char *data2, int pos2, int len2, int XDROP,
		    Feature_assemble *feature);

int alignment_SG_Border(char *data1, int pos1, int len1,
			char *data2, int pos2, int len2, int XDROP,
			Feature_assemble *feature);

int alignment_SG_on_MA(char *data1, char *data2, MA * ma,int left_correction,
		       Feature_assemble *feature);

/*-----------*/

/*-----------------------------------------------------------------*/
/*
 * statistical functions 
 *  - (compute transition/transversion ratio)
 *  - (compute triplet mutation frequency)
 *
 * WARNING : set in "data1" its reversed complementary "datarev" 
 * if needed.
 * coordonninate "pos1" must then be explicitely expressed  
 * (as  (datasize1 - k + 1) - pos1).
 */

/* alignment SG  ( Substitionmatrix + Gap open/continue ) 
 */
/* $ int     cost_gap_opened
 * $ int     cost_gap_continued 
 * $ int[16] substitution_matrix
 */


int alignment_SG_stats(char *data1, int pos1, int len1,
		       char *data2, int pos2, int len2,
		       /*out */ int *trans /*[2] */ ,
		       /*out */ int *stats_data1 /*[3] */ ,
		       /*out */ int *stats_data2 /*[3] */ );

int alignment_SG_stats_Strait(char *data1, int pos1, char *data2, int pos2,
			      int len,
			      /*out */ int *trans /*[2] */ ,
			      /*out */ int *stats_data1 /*[3] */ ,
			      /*out */ int *stats_data2 /*[3] */ );

int alignment_SG_stats_on_MA(char *data1, char *data2, MA * ma,
			     /*out */ int *trans /*[2] */ ,
			     /*out */ int *stats_data1 /*[3] */ ,
			     /*out */ int *stats_data2 /*[3] */ ,
			     int left_correction);


/*-----------------------------------------------------------------*/

/* visual functions:
 *
 * WARNING : set in "data1" its reversed complementary "datarev" 
 * if needed.
 * coordonninate "pos1" must then be explicitely expressed  
 * (as  (datasize1 - k + 1) - pos1).
 */


/* classical simple alignement 
 */

int display_alignment_noflush(int reverse,
			      char *data1, int pos1, int len1,
			      char *data2, int pos2, int len2);

int display_alignment(int reverse,
		      char *data1, int pos1, int len1,
		      char *data2, int pos2, int len2);

int display_alignment_on_MA(char *data1, char *data2, MA * ma);


/* alignment SG ( Substitionmatrix + Gap open/continue ) 
 */

/* $ int     cost_gap_opened
 * $ int     cost_gap_continued 
 * $ int[16] substitution_matrix
 */

int display_alignment_SG_noflush(int reverse,
				 char *data1, int pos1, int len1,
				 char *data2, int pos2, int len2);

int display_alignment_SG(int reverse,
			 char *data1, int pos1, int len1,
			 char *data2, int pos2, int len2);

int display_alignment_SG_on_MA(char *data1, char *data2, MA * ma);

/*-----------------------------------------------------------------*/

int alignment_score(char * data1, char * data2,MA * firstMa,
		    int left_correction);
int alignment_SG_score_on_MA(char * data1, char * data2,
			     MA * ma,int left_correction);
int alignment_SG_score_Strait(char * data1,  int pos1, 
			      char * data2,  int pos2, int len,
			      /*out*/int    *p_score);
int alignment_SG_score(char * data1, int pos1, int len1,
		       char * data2, int pos2, int len2,
		       /*out*/int    *p_score
		       );


#endif

==> yass-1.10.tar.gz: yass-1.10/prdyn.h <==
/*
 *  YASS 1.10
 *  Copyright (C) 2004,2005
 *  YASS Team
 *  Laurent Noe, Gregory Kucherov, Mikhail Roytberg, 
 *  Christophe Valmir, Steven Corroy
 *
 *  noe|<A>|lifl.fr
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software contains code derived from the GNU libavl library.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef __PRDYN_H_
#define __PRDYN_H_

#include "global_var.h"
#include "tuple.h"
#include "threads.h"


int initialise_alignment(int size,Feature *feature);


int left_alignment(char *data1, int pos1, int len1,
		   char *data2, int pos2, int len2,
		   double leavethreshold, int steps_to_leave,
		   /*out */ int *p_gain_score,
		   /*out */ int *p_last_pos1,
		   /*out */ int *p_last_pos2,
		   Feature *feature
		   );

int right_alignment(char *data1, int pos1, int len1,
		    char *data2, int pos2, int len2,
		    double leavethreshold, int steps_to_leave,
		    /*out */ int *p_gain_score,
		    /*out */ int *p_last_pos1,
		    /*out */ int *p_last_pos2,
		    Feature *feature
		    );

int left_alignment_SG(char *data1, int pos1, int len1,
		      char *data2, int pos2, int len2, int XDROP,
		      /*out */ int *p_gainscore,
		      /*out */ int *p_last_pos1,
		      /*out */ int *p_last_pos2,
		      Feature *feature
		      );

int right_alignment_SG(char *data1, int pos1, int len1,
		       char *data2, int pos2, int len2, int XDROP,
		       /*out */ int *p_gainscore,
		       /*out */ int *p_last_pos1,
		       /*out */ int *p_last_pos2,
		       Feature *feature
		       );

int left_alignment_SG_Diag (char * data1, int pos1, int len1,
			    char * data2, int pos2, int len2, 
			    int XDROP, 
			    /*out*/ int * p_gainscore,
			    /*out*/ int * p_last_pos1,
			    /*out*/ int * p_last_pos2,
			    Feature *feature);

int right_alignment_SG_Diag (char * data1, int pos1, int len1,
			     char * data2, int pos2, int len2, 
			     int XDROP, 
			     /*out*/ int * p_gainscore,
			     /*out*/ int * p_last_pos1,
			     /*out*/ int * p_last_pos2,
			     Feature *feature);

int left_alignment_SG_Lz(char *data1, int pos1, int len1,
			 char *data2, int pos2, int len2, int XDROP,
			 /*out */ int *p_gainscore,
			 /*out */ int *p_last_pos1,
			 /*out */ int *p_last_pos2,
			 Feature *feature
			 );

int right_alignment_SG_Lz(char *data1, int pos1, int len1,
			  char *data2, int pos2, int len2, int XDROP,
			  /*out */ int *p_gainscore,
			  /*out */ int *p_last_pos1,
			  /*out */ int *p_last_pos2,
			  Feature *feature
			  );

int left_alignment_SG_Border(char *data1, int pos1, int len1,
			     char *data2, int pos2, int len2, int XDROP,
			     /*out */ int *p_gainscore,
			     /*out */ int *p_last_pos1,
			     /*out */ int *p_last_pos2,
			     Feature *feature
			     );

int right_alignment_SG_Border(char *data1, int pos1, int len1,
			      char *data2, int pos2, int len2, int XDROP,
			      /*out */ int *p_gainscore,
			      /*out */ int *p_last_pos1,
			      /*out */ int *p_last_pos2,
			      Feature *feature
			      );


/*-----------------------------------------------------------------*/

/* alignment methods:
 *
 * WARNING : set in "data1" its reversed complementary "datarev" 
 * if needed.
 * coordonninate "pos1" must then be explicitely expressed  
 * (as  (datasize1 - k + 1) - pos1).
 */

int alignment(char *data1, int pos1, int len1,
	      char *data2, int pos2, int len2,
	      Feature *feature);

int alignment_SG(char *data1, int pos1, int len1,
		 char *data2, int pos2, int len2,
		 Feature *feature);

int alignment_SG_Strait(char *data1, int pos1,
			char *data2, int pos2, int len,
			Feature *feature);

int alignment_SG_DROP(char *data1, int pos1, int len1,
		      char *data2, int pos2, int len2, int XDROP,
		      Feature *feature);


int alignment_SG_DROP_opt(char *data1, int pos1, int len1,
			  char *data2, int pos2, int len2, int XDROP,
			  Feature *feature);

int alignment_SG_Lz(char *data1, int pos1, int len1,
		    char *data2, int pos2, int len2, int XDROP,
		    Feature *feature);

int alignment_SG_Border(char *data1, int pos1, int len1,
			char *data2, int pos2, int len2, int XDROP,
			Feature *feature);

int alignment_SG_on_MA(char *data1, char *data2, MA * ma,int left_correction,
		       Feature *feature);

/*-----------*/

/*-----------------------------------------------------------------*/
/*
 * statistical functions 
 *  - (compute transition/transversion ratio)
 *  - (compute triplet mutation frequency)
 *
 * WARNING : set in "data1" its reversed complementary "datarev" 
 * if needed.
 * coordonninate "pos1" must then be explicitely expressed  
 * (as  (datasize1 - k + 1) - pos1).
 */

/* alignment SG  ( Substitionmatrix + Gap open/continue ) 
 */
/* $ int     cost_gap_opened
 * $ int     cost_gap_continued 
 * $ int[16] substitution_matrix
 */


int alignment_SG_stats(char * data1, int pos1, int len1,
		       char * data2, int pos2, int len2,
		       /*out*/int * transindels      /*[3]*/,
		       /*out*/int * trinomial_count1 /*[3]*/,
		       /*out*/int * trinomial_count2 /*[3]*/,
		       /*out*/int * mutatedword1,
		       /*out*/int * mutatedword2,
		       /*out*/int * nonmutatedword,
		       /*out*/int * mutatedword_count1  /* [4^3] */,
		       /*out*/int * mutatedword_count2  /* [4^3] */,
		       /*out*/int * nonmutatedword_count/* [4^3] */);

int alignment_SG_stats_Strait(char * data1,  int pos1, char * data2,  int pos2, int len,
			      /*out*/int * transindels      /*[3]*/,
			      /*out*/int * trinomial_count1 /*[3]*/,
			      /*out*/int * trinomial_count2 /*[3]*/,
			      /*out*/int * mutatedword1,
			      /*out*/int * mutatedword2,
			      /*out*/int * nonmutatedword,
			      /*out*/int * mutatedword_count1 /* [4^3] */,
			      /*out*/int * mutatedword_count2 /* [4^3] */,
			      /*out*/int * nonmutatedword_count  /* [4^3] */);

int alignment_SG_stats_on_MA(char * data1, char * data2,
			     MA * ma,
			     int left_correction,
			     /*out*/int * transindels      /*[3]*/,
			     /*out*/int * trinomial_count1 /*[3]*/,
			     /*out*/int * trinomial_count2 /*[3]*/,
			     /*out*/int * mutatedword_count1 /* [4^3] */,
			     /*out*/int * mutatedword_count2 /* [4^3] */,
			     /*out*/int * nonmutatedword_count  /* [4^3] */);

int alignment_SG_stats_on_strait_MA(char * data1, char * data2,
 			     MA * ma,
			     int left_correction,
			     /*out*/int * transindels      /*[3]*/,
			     /*out*/int * trinomial_count1 /*[3]*/,
			     /*out*/int * trinomial_count2 /*[3]*/,
                             /*out*/int * mutatedword_count1 /* [4^3] */,
			     /*out*/int * mutatedword_count2 /* [4^3] */,
				    /*out*/int * nonmutatedword_count  /* [4^3] */);


/*-----------------------------------------------------------------*/

/* visual functions:
 *
 * WARNING : set in "data1" its reversed complementary "datarev" 
 * if needed.
 * coordonninate "pos1" must then be explicitely expressed  
 * (as  (datasize1 - k + 1) - pos1).
 */


/* classical simple alignement 
 */

int display_alignment_noflush(int reverse,
			      char *data1, int pos1, int len1,
			      char *data2, int pos2, int len2);

int display_alignment(int reverse,
		      char *data1, int pos1, int len1,
		      char *data2, int pos2, int len2);

int display_alignment_on_MA(char *data1, char *data2, MA * ma);


/* alignment SG ( Substitionmatrix + Gap open/continue ) 
 */

/* $ int     cost_gap_opened
 * $ int     cost_gap_continued 
 * $ int[16] substitution_matrix
 */

int display_alignment_SG_noflush(int reverse,
				 char *data1, int pos1, int len1,
				 char *data2, int pos2, int len2);

int display_alignment_SG(int reverse,
			 char *data1, int pos1, int len1,
			 char *data2, int pos2, int len2);

int display_alignment_SG_on_MA(char *data1, char *data2, MA * ma);

/*-----------------------------------------------------------------*/

int alignment_SG_score_on_MAs(char * data1, char * data2,MA * firstMa,
		       int left_correction);
int alignment_SG_score_on_MA(char * data1, char * data2,
			     MA * ma,int left_correction);
int alignment_SG_score_Strait(char * data1,  int pos1, 
			      char * data2,  int pos2, int len,
			      /*out*/int    *p_score);
int alignment_SG_score(char * data1, int pos1, int len1,
		       char * data2, int pos2, int len2,
		       /*out*/int    *p_score
		       );


#endif
